#ifndef _diskload_h
#define _diskload_h


struct Diskload
{
  float readkbytespersec;
  float writekbytespersec;
};


#endif // _diskload_h
